pub enum HttpMethod {
GET,
PUT,
PATCH,
DELETE,
POST,
}Expand description
HttpMethod : The HTTP method associated with the individual APIs being called as part of the batch request. The HTTP method associated with the individual APIs being called as part of the batch request.
Variants
GET
PUT
PATCH
DELETE
POST